# -*- coding: utf-8 -*-

import os
import sys
import logging
from logging.handlers import RotatingFileHandler

from cmutils.config_loaders import IniConfigLoader
from dropshipping.utils.offer_services import EsOfferService
from em_tasks.utils.product_service import ProductService


logger = logging.getLogger('em_celery.' + __name__)
formatter = logging.Formatter('%(asctime)s [%(levelname)s]: %(message)s')
logger.setLevel(logging.DEBUG)
stream_handler = logging.StreamHandler(sys.stdout)
stream_handler.setFormatter(formatter)
logger.addHandler(stream_handler)

_cfg = None

def get_config():
  if _cfg is None:
    config_path = os.getenv(
      'MWS_COLLECTOR_CONFIGURATION_PATH',
      os.path.join('~', '.em_celery', 'config.ini'))
    config = IniConfigLoader(config_path)
    _cfg = config.load()

  return _cfg

def get_product_service():
  config = get_config()
  product_cfg = config['product_service']
  return ProductService(
    product_cfg['host'], product_cfg['port'], product_cfg['user'], product_cfg['password'])

def get_offer_service():
  config = get_config()
  offer_cfg = config['offer_service']
  return EsOfferService(
    offer_cfg['host'], offer_cfg['port'], offer_cfg['user'], offer_cfg['password'])
